# HiveNetNoSql

HiveNetNoSql is a general NoSQL data access driver framework. Referring to the syntax of MongoDB, it abstracts the data access operations of NoSQL to facilitate the data access of various databases (including relational databases and NoSQL databases) using the same set of NoSQL operations. In this package, the driver adaptation of MongoDB, Sqlite, MySQL and Postgresql is implemented, and the adaptation of other databases can be implemented according to their own needs.

docs: https://hivenetassemble.readthedocs.io/zh_CN/latest/
